@@ -18,7 +18,6 @@ from pybana.translators.elastic.buckets import (
     format_from_interval,
     compute_auto_interval,
 )
-from pybana.helpers import numeral2d3
 
 PYBANA_INDEX = ".kibana_pybana_test"
 elastic = elasticsearch.Elasticsearch()
@@ -35,7 +34,8 @@ def load_fixtures(elastic, kibana, index):
     def actions():
         with open(datafn, "r") as fd:
             for line in fd:
-
+                if not line:
+                    continue
                 action = json.loads(line)
                 action["_index"] = index
                 yield action
@@ -95,7 +95,7 @@ def test_client():
     kibana.update_or_create_default_index_pattern(index_pattern)
     kibana.update_or_create_default_index_pattern(index_pattern)
     visualizations = list(kibana.visualizations().scan())
-    assert len(visualizations) == 23
+    assert len(visualizations) == 26
     visualization = kibana.visualization("6eab7cb0-fb18-11e9-84e4-078763638bf3")
     visualization.visState
     visualization.uiStateJSON
@@ -144,11 +144,39 @@ def test_translators():
                 "9a4d3520-013f-11ea-b1ec-3910cd795dc1",
                 "53b3da70-fbbc-11e9-84e4-078763638bf3",
                 "c36b8b00-6f85-11ea-85b8-8f688e91da4a",
+                "e8c08560-7276-11ea-a6e2-834e20d9c131",
             ):
                 response = search.execute()
                 VegaTranslator().translate(visualization, response, scope)
 
 
+def test_vega_visuzalization():
+    kibana = Kibana(PYBANA_INDEX)
+    load_fixtures(elastic, kibana, PYBANA_INDEX)
+    load_data(elastic, "pybana")
+    kibana.init_config()
+    translator = ElasticTranslator()
+    scope = Scope(
+        datetime.datetime(2019, 1, 1, tzinfo=pytz.utc),
+        datetime.datetime(2019, 1, 3, tzinfo=pytz.utc),
+        pytz.utc,
+        kibana.config(),
+    )
+    keys = [
+        "37589ee0-70f3-11ea-9898-e1fb79cbf2bc",
+        "da8f8510-7107-11ea-9898-e1fb79cbf2bc",
+    ]
+    for key in keys:
+        visualization = kibana.visualization(key)
+        search = translator.translate(visualization, scope)
+        assert (
+            search.to_dict()["aggs"]["category"]["date_histogram"]["interval"] == "1h"
+        )
+
+        response = search.execute()
+        VegaTranslator().translate(visualization, response, scope)
+
+
 def test_elastic_translator_helpers():
     assert format_from_interval("1y") == "yyyy"
     assert format_from_interval("1q") == "yyyy-MM"
@@ -215,16 +243,3 @@ def test_datasweet():
     with pytest.raises(ValueError):
         tree = ast.parse("x + 1", mode="eval")
         tree = ds.DatasweetTransformer().visit(tree)
-
-
-def test_numeral2d3():
-    assert numeral2d3(None) == ""
-    assert numeral2d3("") == ""
-    assert numeral2d3("00:00:00") == ""
-    assert numeral2d3("0.0%") == ".1%"
-    assert numeral2d3("0.00%") == ".2%"
-    assert numeral2d3("0.00 %") == ".2%"
-    assert numeral2d3("0") == ".0f"
-    assert numeral2d3("0.0") == ".1f"
-    assert numeral2d3("0.00") == ".2f"
-    assert numeral2d3("0.000") == ".3f"
